@@ -1,7 +1,7 @@
 #include "util.h"
 
 #define DEFAULT_SYSUSRTMP "/tmp/user"
-#define CONFIG_FILE "/etc/pam-tmpdir.conf"
+#define CONFIG_FILE "/etc/security/tmpdir.conf"
 
 /* Standard implementation of xrealloc -- exit if anything goes
    wrong */
@@ -42,11 +42,6 @@ char *freadline(FILE *stream) {
   ret = xmalloc(sizeof(buf));
   strcpy(ret, buf);
   t = fgets(buf, sizeof(buf), stream);
-  while (t != NULL) {
-    alloc += (strlen(t));
-    ret = xrealloc(ret, alloc);
-    strcat(ret,buf);
-  }
   return ret;
 }
 
@@ -59,7 +54,7 @@ int check_dir_ok(char *path) {
     return 1;
   } else if (statbuf.st_uid != 0) {
     /* Somebody else than root has grabbed the dir.  Bad, bad, bad. */
-    _log_err(LOG_ERR, "%s is owned by uid %d instead of root " 
+    _log_err(LOG_ERR, "%s is owned by uid %d instead of root "
 	    "(uid 0).\n", path, statbuf.st_uid);
     return 1;
   } else if (!S_ISDIR(statbuf.st_mode)) {
@@ -77,7 +72,7 @@ int check_path(const char *path) {
   char *tmp;
 
   /* special-case /, since it should end with / */
-  
+
   if (check_dir_ok("/") != 0) {
     free(p);
     return 1;
@@ -127,6 +122,7 @@ char *get_tmp_dir() {
     char *key, *value;
     if ((line[0] == '#') || (strchr(line, '=') == NULL)) {
       free(line);
+      line = freadline(conf);
       continue;
     }
     tmp = strchr(line, '=');
@@ -157,7 +153,7 @@ char *get_tmp_dir() {
 
 void _log_err(int err, const char *format, ...) {
   va_list args;
-  
+
   va_start(args, format);
   openlog("PAM_tmpdir", LOG_CONS|LOG_PID, LOG_AUTH);
   vsyslog(err, format, args);
